<!--startmeta
custom_edit_url: "https://github.com/netdata/netdata/edit/master/src/collectors/python.d.plugin/retroshare/README.md"
meta_yaml: "https://github.com/netdata/netdata/edit/master/src/collectors/python.d.plugin/retroshare/metadata.yaml"
sidebar_label: "RetroShare"
learn_status: "Published"
learn_rel_path: "Collecting Metrics/Media Services"
most_popular: False
message: "DO NOT EDIT THIS FILE DIRECTLY, IT IS GENERATED BY THE COLLECTOR'S metadata.yaml FILE"
endmeta-->

# RetroShare


<img src="https://netdata.cloud/img/retroshare.png" width="150"/>


Plugin: python.d.plugin
Module: retroshare

<img src="https://img.shields.io/badge/maintained%20by-Netdata-%2300ab44" />

## Overview

This collector monitors RetroShare statistics such as application bandwidth, peers, and DHT metrics.

It connects to the RetroShare web interface to gather metrics.

This collector is supported on all platforms.

This collector supports collecting metrics from multiple instances of this integration, including remote instances.


### Default Behavior

#### Auto-Detection

The collector will attempt to connect and detect a RetroShare web interface through http://localhost:9090, even without any configuration.

#### Limits

The default configuration for this integration does not impose any limits on data collection.

#### Performance Impact

The default configuration for this integration is not expected to impose a significant performance impact on the system.


## Metrics

Metrics grouped by *scope*.

The scope defines the instance that the metric belongs to. An instance is uniquely identified by a set of labels.



### Per RetroShare instance

These metrics refer to the entire monitored application.

This scope has no labels.

Metrics:

| Metric | Dimensions | Unit |
|:------|:----------|:----|
| retroshare.bandwidth | Upload, Download | kilobits/s |
| retroshare.peers | All friends, Connected friends | peers |
| retroshare.dht | DHT nodes estimated, RS nodes estimated | peers |



## Alerts


The following alerts are available:

| Alert name  | On metric | Description |
|:------------|:----------|:------------|
| [ retroshare_dht_working ](https://github.com/netdata/netdata/blob/master/src/health/health.d/retroshare.conf) | retroshare.dht | number of DHT peers |


## Setup

### Prerequisites

#### RetroShare web interface

RetroShare needs to be configured to enable the RetroShare WEB Interface and allow access from the Netdata host.



### Configuration

#### File

The configuration file name for this integration is `python.d/retroshare.conf`.


You can edit the configuration file using the `edit-config` script from the
Netdata [config directory](https://github.com/netdata/netdata/blob/master/docs/netdata-agent/configuration.md#the-netdata-config-directory).

```bash
cd /etc/netdata 2>/dev/null || cd /opt/netdata/etc/netdata
sudo ./edit-config python.d/retroshare.conf
```
#### Options

There are 2 sections:

* Global variables
* One or more JOBS that can define multiple different instances to monitor.

The following options can be defined globally: priority, penalty, autodetection_retry, update_every, but can also be defined per JOB to override the global values.

Additionally, the following collapsed table contains all the options that can be configured inside a JOB definition.

Every configuration JOB starts with a `job_name` value which will appear in the dashboard, unless a `name` parameter is specified.


<details><summary>Config options</summary>

| Name | Description | Default | Required |
|:----|:-----------|:-------|:--------:|
| update_every | Sets the default data collection frequency. | 5 | no |
| priority | Controls the order of charts at the netdata dashboard. | 60000 | no |
| autodetection_retry | Sets the job re-check interval in seconds. | 0 | no |
| penalty | Indicates whether to apply penalty to update_every in case of failures. | yes | no |
| name | Job name. This value will overwrite the `job_name` value. JOBS with the same name are mutually exclusive. Only one of them will be allowed running at any time. This allows autodetection to try several alternatives and pick the one that works. |  | no |
| url | The URL to the RetroShare Web UI. | http://localhost:9090 | no |

</details>

#### Examples

##### Local RetroShare Web UI

A basic configuration for a RetroShare server running on localhost.

<details><summary>Config</summary>

```yaml
localhost:
 name: 'local retroshare'
 url: 'http://localhost:9090'

```
</details>

##### Remote RetroShare Web UI

A basic configuration for a remote RetroShare server.

<details><summary>Config</summary>

```yaml
remote:
 name: 'remote retroshare'
 url: 'http://1.2.3.4:9090'

```
</details>



## Troubleshooting

### Debug Mode

To troubleshoot issues with the `retroshare` collector, run the `python.d.plugin` with the debug option enabled. The output
should give you clues as to why the collector isn't working.

- Navigate to the `plugins.d` directory, usually at `/usr/libexec/netdata/plugins.d/`. If that's not the case on
  your system, open `netdata.conf` and look for the `plugins` setting under `[directories]`.

  ```bash
  cd /usr/libexec/netdata/plugins.d/
  ```

- Switch to the `netdata` user.

  ```bash
  sudo -u netdata -s
  ```

- Run the `python.d.plugin` to debug the collector:

  ```bash
  ./python.d.plugin retroshare debug trace
  ```


